@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright 2015-2021 Mike Fährmann
+# Copyright 2015-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -312,6 +312,7 @@ def setup_test_config():
 
     config.set(("extractor", "nijie")     , "username", email)
     config.set(("extractor", "seiga")     , "username", email)
+    config.set(("extractor", "horne")     , "username", email2)
     config.set(("extractor", "pinterest") , "username", email2)
     config.set(("extractor", "pinterest") , "username", None)  # login broken
 
@@ -322,7 +323,8 @@ def setup_test_config():
     config.set(("extractor", "mangoxo")   , "password", "5zbQF10_5u25259Ma")
 
     for category in ("danbooru", "instagram", "twitter", "subscribestar",
-                     "e621", "inkbunny", "tapas", "pillowfort", "mangadex"):
+                     "e621", "atfbooru", "inkbunny", "tapas", "pillowfort",
+                     "mangadex"):
         config.set(("extractor", category), "username", None)
 
     config.set(("extractor", "mastodon.social"), "access-token",
@@ -353,28 +355,23 @@ def generate_tests():
 
     # enable selective testing for direct calls
     if __name__ == '__main__' and len(sys.argv) > 1:
-        if sys.argv[1].lower() == "all":
-            fltr = lambda c, bc: True  # noqa: E731
-        elif sys.argv[1].lower() == "broken":
-            fltr = lambda c, bc: c in BROKEN  # noqa: E731
-        else:
-            argv = sys.argv[1:]
-            fltr = lambda c, bc: c in argv or bc in argv  # noqa: E731
+        categories = sys.argv[1:]
+        negate = False
+        if categories[0].lower() == "all":
+            categories = ()
+            negate = True
+        elif categories[0].lower() == "broken":
+            categories = BROKEN
         del sys.argv[1:]
     else:
-        skip = set(BROKEN)
-        if skip:
-            print("skipping:", ", ".join(skip))
-        fltr = lambda c, bc: c not in skip  # noqa: E731
-
-    # filter available extractor classes
-    extractors = [
-        extr for extr in extractor.extractors()
-        if fltr(extr.category, extr.basecategory)
-    ]
+        categories = BROKEN
+        negate = True
+        if categories:
+            print("skipping:", ", ".join(categories))
+    fltr = util.build_extractor_filter(categories, negate=negate)
 
     # add 'test_...' methods
-    for extr in extractors:
+    for extr in filter(fltr, extractor.extractors()):
         name = "test_" + extr.__name__ + "_"
         for num, tcase in enumerate(extr._get_tests(), 1):
             test = _generate_test(extr, tcase)
